@@ -1,14 +1,12 @@
 package Git::CPAN::Patch::Command::SendEmail;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: use C<git-send-email> to submit patches to CPAN RT
-$Git::CPAN::Patch::Command::SendEmail::VERSION = '2.3.2';
+$Git::CPAN::Patch::Command::SendEmail::VERSION = '2.3.3';
 use 5.10.0;
 
 use strict;
 use warnings;
 
-use Method::Signatures::Simple;
-
 use MooseX::App::Command;
 
 with 'Git::CPAN::Patch::Role::Git';
@@ -20,9 +18,7 @@ parameter extra_arg => (
     required => 0,
 );
 
-method run {
-    $self->send_emails($self->extra_arg);
-}
+sub run { $_[0]->send_emails($_[0]->extra_arg) }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -40,7 +36,7 @@ Git::CPAN::Patch::Command::SendEmail - use C<git-send-email> to submit patches t
 
 =head1 VERSION
 
-version 2.3.2
+version 2.3.3
 
 =head1 SYNOPSIS
 
@@ -57,7 +53,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
