@@ -1,20 +1,23 @@
 package Git::CPAN::Patch::Command::SendPatch;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: create patch files and submit them to RT
-$Git::CPAN::Patch::Command::SendPatch::VERSION = '2.3.2';
+$Git::CPAN::Patch::Command::SendPatch::VERSION = '2.3.3';
 use 5.10.0;
 
 use strict;
 use warnings;
 
-use Method::Signatures::Simple;
-
 use MooseX::App::Command;
 
 with 'Git::CPAN::Patch::Role::Git';
 with 'Git::CPAN::Patch::Role::Patch';
 
-method run {
+use experimental qw/
+    signatures
+    postderef
+/;
+
+sub run ($self) {
     $self->format_patch;
 
     if ( $self->nbr_patches > 1 ) {
@@ -45,7 +48,7 @@ Git::CPAN::Patch::Command::SendPatch - create patch files and submit them to RT
 
 =head1 VERSION
 
-version 2.3.2
+version 2.3.3
 
 =head1 SYNOPSIS
 
@@ -65,7 +68,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
