@@ -1,19 +1,23 @@
 package Git::CPAN::Patch::Command::Squash;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Combine multiple commits into one patch
-$Git::CPAN::Patch::Command::Squash::VERSION = '2.3.2';
+$Git::CPAN::Patch::Command::Squash::VERSION = '2.3.3';
 use 5.10.0;
 
 use strict;
 use warnings;
 
-use Method::Signatures::Simple;
 use Git::Repository;
 
 use MooseX::App::Command;
 
 with 'Git::CPAN::Patch::Role::Git';
 
+use experimental qw/
+    signatures
+    postderef
+/;
+
 has first_arg => (
     is => 'ro',
     isa => 'Str',
@@ -24,12 +28,12 @@ has branch => (
     is => 'ro',
     isa => 'Str',
     lazy => 1,
-    default => method {
+    default => sub ($self) {
         $self->first_arg || 'patch';
     },
 );
 
-method run {
+sub run ($self) {
     my $head = $self->git_run("rev-parse", "--verify", "HEAD");
 
     say for $self->git_run("checkout", "-b", $self->branch, "cpan/master");
@@ -57,7 +61,7 @@ Git::CPAN::Patch::Command::Squash - Combine multiple commits into one patch
 
 =head1 VERSION
 
-version 2.3.2
+version 2.3.3
 
 =head1 SYNOPSIS
 
@@ -84,7 +88,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
