@@ -1,19 +1,22 @@
 package Git::CPAN::Patch::Command::Update;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Import the latest version of a module and rebase the current branch
-$Git::CPAN::Patch::Command::Update::VERSION = '2.3.2';
+$Git::CPAN::Patch::Command::Update::VERSION = '2.3.3';
 use 5.10.0;
 
 use strict;
 use warnings;
 
-use Method::Signatures::Simple;
 use Git::Repository;
 
 use MooseX::App::Command;
 
 extends 'Git::CPAN::Patch::Command::Import';
 
+use experimental qw/
+    signatures
+    postderef
+/;
 
 #TODO check for versions before download
 
@@ -21,19 +24,18 @@ has last_import_before_run => (
     is => 'rw',
 );
 
-before run => method {
+before run => sub ($self) {
     eval { $self->set_last_import_before_run($self->last_commit) }
         or die "branch 'cpan/master' doesn't exist yet (import first)\n";
     $self->set_thing_to_import( $self->tracked_distribution );
 };
 
-after run => method {
+after run => sub ($self) {
     return if $self->last_import_before_run eq $self->last_commit;
 
     $self->git_run( rebase => 'cpan/master' );
 };
 
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -50,7 +52,7 @@ Git::CPAN::Patch::Command::Update - Import the latest version of a module and re
 
 =head1 VERSION
 
-version 2.3.2
+version 2.3.3
 
 =head1 SYNOPSIS
 
@@ -78,7 +80,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
