@@ -1,21 +1,18 @@
 package Git::CPAN::Patch::Command::Which;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: reports the repository's module
-$Git::CPAN::Patch::Command::Which::VERSION = '2.3.2';
+$Git::CPAN::Patch::Command::Which::VERSION = '2.3.3';
 use 5.10.0;
 
 use strict;
 use warnings;
 
-use Method::Signatures::Simple;
 use MooseX::App::Command;
 
 with 'Git::CPAN::Patch::Role::Git';
 with 'Git::CPAN::Patch::Role::Patch';
 
-method run {
-    say $self->module_name;
-}
+sub run { say $_[0]->module_name }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -33,7 +30,7 @@ Git::CPAN::Patch::Command::Which - reports the repository's module
 
 =head1 VERSION
 
-version 2.3.2
+version 2.3.3
 
 =head1 SYNOPSIS
 
@@ -59,7 +56,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
