@@ -1,11 +1,10 @@
 package Git::CPAN::Patch::Role::Git;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: provides access to Git repository
-$Git::CPAN::Patch::Role::Git::VERSION = '2.3.2';
+$Git::CPAN::Patch::Role::Git::VERSION = '2.3.3';
 use strict;
 use warnings;
 
-use Method::Signatures::Simple;
 use version;
 
 use Moose::Role;
@@ -14,6 +13,11 @@ use MooseX::SemiAffordanceAccessor;
 
 use Git::Repository;
 
+use experimental qw/
+    signatures
+    postderef
+/;
+
 option root => (
     is => 'rw',
     isa => 'Str',
@@ -25,7 +29,7 @@ has git => (
     is => 'ro',
     isa => 'Git::Repository',
     lazy => 1,
-    default => method {
+    default => sub ($self) {
         Git::Repository->new(
             work_tree => $self->root
         );
@@ -35,11 +39,11 @@ has git => (
     },
 );
 
-method last_commit {
+sub last_commit ($self) {
     eval { $self->git_run('rev-parse', '--verify', 'cpan/master') }
 }
 
-method last_imported_version {
+sub last_imported_version  ($self) {
     my $last_commit = $self->last_commit or return version->parse(0);
 
     my $last = join "\n", $self->git_run( log => '--pretty=format:%b', '-n', 1, $last_commit );
@@ -50,7 +54,7 @@ method last_imported_version {
     return version->parse($2);
 }
 
-method tracked_distribution {
+sub tracked_distribution ($self) {
     my $last_commit = $self->last_commit or return;
 
     my $last = join "\n", $self->git_run( log => '--pretty=format:%b', '-n', 1, $last_commit );
@@ -61,9 +65,7 @@ method tracked_distribution {
     return $1;
 }
 
-method first_import {
-    return !$self->last_commit;
-}
+sub first_import { return !$_[0]->last_commit }
 
 1;
 
@@ -79,7 +81,7 @@ Git::CPAN::Patch::Role::Git - provides access to Git repository
 
 =head1 VERSION
 
-version 2.3.2
+version 2.3.3
 
 =head1 AUTHOR
 
@@ -87,7 +89,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011, 2010, 2009 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
